![Black Logo](https://gitlab.com/martinbaun/swat-em/-/raw/master/doc/source/fig/logo.png)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Actions Status](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)



SWAT-EM
=======

Specific Winding Analyse Tool for Electrical Machines


Installation
------------

To install, you can do:

```
pip install swat-em
```

or download it from [https://gitlab.com/martinbaun/swat-em/](https://gitlab.com/martinbaun/swat-em/) and
install it from the project root directory:

```
python setup.py install
```

If you running windows and don't want to deal with a python interpreter
you can download an *.exe installer or a  portable *.zip version which 
includes all python dependencies from [https://sourceforge.net/projects/swat-em/](https://sourceforge.net/projects/swat-em/)

Run the programm
----------------

Run the programm by starting it from the command line

```
swat-em
```

or with:

    swat-em.exe
    
under windows. If you have installed swat-em with the windows installer
you can use the desktop icon to start.


Documentation
-------------
Find the docs on [https://swat-em.readthedocs.io/en/latest/index.html#](https://swat-em.readthedocs.io/en/latest/index.html#)
